**Example 1: 删除Amqp路由关系**



Input: 

```
tccli tdmq DeleteAMQPRouteRelation --cli-unfold-argument  \
    --VHostId test \
    --RouteRelationId rr-sfsffs \
    --ClusterId amqp-dsadasd
```

Output: 
```
{
    "Response": {
        "RequestId": "0604a303-6d5f-40e6-9dfe-6c4ddd8fe2df"
    }
}
```

